<?php
namespace Neklo\Scheduler\Controller\Adminhtml\Job;

use Neklo\Scheduler\Controller\Adminhtml;
use Neklo\Scheduler\Api\Data\JobInterface;

class Edit extends Adminhtml\Action
{

    /**
     * Redirect url
     */
    const REDIRECT_URL = '*/index/jobs';
    const MODEL_REGISTRY = 'edit_job';

    protected function _initAction($resultPage)
    {
        parent::_initAction($resultPage);
        $resultPage->setActiveMenu('Neklo_Scheduler::jobs');
    }

    public function execute()
    {
        $this->setupModel();

        $resultPage = $this->resultPageFactory->create();
        $this->_initAction($resultPage);
        $resultPage->addBreadcrumb(
            __('Edit Job'),
            __('Edit Job'));
        $resultPage->getConfig()->getTitle()->prepend(__('Cron Scheduler'));
        return $resultPage;
    }

    protected function setupModel()
    {
        $id = $this->getRequest()->getParam(JobInterface::JOB_ID);
        $model = $this->_objectManager->create('Neklo\Scheduler\Model\Job');

        if ($id) {
            $model->load($id);
            if (!$model->getId()) {
                $this->messageManager
                    ->addError(__('This job ID(%1) no longer exists.'));
                $resultRedirect = $this->resultRedirectFactory->create();
                return $resultRedirect->setPath(self::REDIRECT_URL);
            }
        }

        // 3. Set entered data if was error when we do save
        $data = $this->_objectManager->get('Magento\Backend\Model\Session')
            ->getFormData(true);
        if (!empty($data)) {
            $model->setData($data);
        }

        // 4. Register model to use later in blocks
        $this->coreRegistry->register(self::MODEL_REGISTRY, $model);
    }

    /**
     * Check if admin has permissions to visit related pages
     *
     * @return bool
     */
    protected function _isAllowed()
    {
        return $this->_authorization
            ->isAllowed('Neklo_Scheduler::edit');
    }
}
