<?php
namespace Neklo\Scheduler\Controller\Adminhtml\Schedule;

use Neklo\Scheduler\Controller\Adminhtml;
use Magento\Backend\App\Action\Context;

class MassDelete extends Adminhtml\Action
{
    /**
     * Redirect url
     */
    const REDIRECT_URL = '*/index/index';
    /**
     * Field id
     */
    const ID_FIELD = 'selected';

    /**
     *
     * @var \Psr\Log\LoggerInterface
     */
    protected $log;
    /**
     *
     * @var \Neklo\Scheduler\Model\JobFactory
     */
    protected $factory;

    public function __construct(
        Context $context,
        \Magento\Framework\View\Result\PageFactory $resultPageFactory,
        \Magento\Framework\Registry $registry,
        \Magento\Cron\Model\ScheduleFactory $modelFactory,
        \Psr\Log\LoggerInterface $logger
    ) {
        parent::__construct($context, $resultPageFactory, $registry);
        $this->log = $logger;
        $this->factory = $modelFactory;
    }

    public function execute()
    {
        $selected = $this->getSelected();
        try {
            if (!empty($selected)) {
                $this->setArray($selected);
            } else {
                $this->messageManager->addError(__('Please select item(s).'));
            }
        } catch (\Exception $e) {
            $this->log->critical($e->getMessage());
            $this->messageManager->addError(__('Operation error'));
        }
        return $this->_redirect(static::REDIRECT_URL);
    }

    protected function setArray($items)
    {
        $errMsg = [];
        foreach ($items as $id) {
            $job = $this->factory->create();
            try {
                $job->load($id);
                if ($job->getId()) {
                    $job->delete($job);
                }
            } catch (\Exception $e) {
                $err = true;
                $this->log->critical($e->getMessage());
                $errMsg[] = __('Job ID: %1 does not exist', $id);
            }
        }
        if (empty($err)) {
            $this->messageManager
                ->addSuccess(__('Jobs ID (%1) updated',implode(',',$items)));
        } else {
            $this->messageManager
                ->addError(implode('<br>', $errMsg));
        }
    }

    protected function getSelected()
    {
        $param = $this->getRequest()->getParam(self::ID_FIELD);
        if (!is_array($param)) {
            $param = explode(',', $param);
        }
        return $param;
    }
    /**
     * Check if admin has permissions to visit related pages
     *
     * @return bool
     */
    protected function _isAllowed()
    {
        return $this->_authorization
            ->isAllowed('Neklo_Scheduler::edit');
    }
}
